
######################################
######    Basic information    #######
######################################

# R code for Supplement S4 of the article "Drastic demographic events triggered the Proto-Uralic spread"
# Date of last update: 12 May 2021


##################################
######    Preliminaries    #######
##################################

### Load necessary packages to R session
# If they are not installed yet, install them first
# pkgs = c("trend")
# install.packages(pkgs, repos = "https://cloud.r-project.org")
library(trend)
library(readxl)


### Read data into the session
# IBD data for languages
ibd_lang <- read_excel("PU_I-I_2021-data.xlsx",
                       sheet = 2)

# IBD data for branches
ibd_br <- read_excel("PU_I-I_2021-data.xlsx",
                  sheet = 3)


##################################
######        Tests        #######
##################################

### Correlation of Uralic etyma and I-I loans
# Excluding Samoyedic
cor.test(ibd_lang$PU_etyma[1:22], ibd_lang$II_Loans[1:22],
         method="k")

# Including Samoyedic
cor.test(ibd_lang$PU_etyma, ibd_lang$II_Loans,
         method="k")



### IBD for retentions of Uralic traits in branches
## Including Samoyedic
# Create the matrix
ur.all = matrix(ncol=3, nrow=5)
colnames(ur.all) = c("tau", "p", "S")
rownames(ur.all) = colnames(ibd_br)[2:6]

# Perform one-sided Mann-Kendall calculations.
# H0: no monotonic trend; H1: negative monotonic trend
# Data is ranked for the test in terms of distances from
# a point of origin.
for(i in 1:nrow(ur.all)){
  mk = mk.test(ibd_br$PU[order(ibd_br[,i+1])],
               alternative = "less")
  # assign tau-values
  ur.all[i,1] <- round(mk$estimates[[3]],3)
  # assign p-values
  ur.all[i,2] <- round(mk$p.value,3)
  # assign S-values
  ur.all[i,3] <- mk$estimates[[1]]
}
ur.all


## Excluding Samoyedic
# Create the matrix
ur.NoSam = matrix(ncol=3, nrow=5)
colnames(ur.NoSam) = c("tau", "p", "S")
rownames(ur.NoSam) = colnames(ibd_br)[2:6]

# Perform one-sided Mann-Kendall calculations.
# H0: no monotonic trend; H1: negative monotonic trend
# Data is ranked for the test in terms of distances
# from a point of origin.
ibd_br.NoSam = ibd_br[ibd_br$Branches !="Samoyedic",]
for(i in 1:nrow(ur.NoSam)){
  mk = mk.test(ibd_br.NoSam$PU[order(ibd_br.NoSam[,i+1])],
               alternative = "less")
  # assign tau-values
  ur.NoSam[i,1] <- round(mk$estimates[[3]],3)
  # assign p-values
  ur.NoSam[i,2] <- round(mk$p.value,3)
  # assign S-values
  ur.NoSam[i,3] <- mk$estimates[[1]]
}
ur.NoSam

### IBD for Indo-Iranian loans
## Including Samoyedic
# Create the matrix
ii.all = matrix(ncol=3, nrow=5)
colnames(ii.all) = c("tau", "p", "S")
rownames(ii.all) = colnames(ibd_br)[2:6]

# Perform one-sided Mann-Kendall calculations.
# H0: no monotonic trend; H1: negative monotonic trend
# Data is ranked for the test in terms of distances
# from a point of origin.
for(i in 1:nrow(ii.all)){
  mk = mk.test(ibd_br$II_Loans[order(ibd_br[,i+1])],
               alternative = "less")
  # assign tau-values
  ii.all[i,1] <- round(mk$estimates[[3]],3)
  # assign p-values
  ii.all[i,2] <- round(mk$p.value,3)
  # assign S-values
  ii.all[i,3] <- mk$estimates[[1]]
}
ii.all

## Excluding Samoyedic
# Create the matrix
ii.NoSam = matrix(ncol=3, nrow=5)
colnames(ii.NoSam) = c("tau", "p", "S")
rownames(ii.NoSam) = colnames(ibd_br)[2:6]

# Perform one-sided Mann-Kendall calculations.
# H0: no monotonic trend; H1: negative monotonic trend
# Data is ranked for the test in terms of distances
# from a point of origin.
for(i in 1:nrow(ii.NoSam)){
  mk = mk.test(ibd_br.NoSam$II_Loans[order(ibd_br.NoSam[,i+1])],
               alternative = "less")
  # assign tau-values
  ii.NoSam[i,1] <- round(mk$estimates[[3]],3)
  # assign p-values
  ii.NoSam[i,2] <- round(mk$p.value,3)
  # assign S-values
  ii.NoSam[i,3] <- mk$estimates[[1]]
}
ii.NoSam




#####################################
### Saamic distances recalculated ###
#####################################

ibd_br.saa = ibd_br
# Distance from Finnihc to Saamic is 281.2km using
# https://www.movable-type.co.uk/scripts/latlong.html
# Update Saamic distances
ibd_br.saa[ibd_br.saa$Branches == "Saamic",2:6] <- 
  ibd_br.saa[ibd_br.saa$Branches == "Finnic",2:6] + 281


### IBD for retentions of Uralic traits in branches
## Including Samoyedic
# Create the matrix
ur.all.saa = matrix(ncol=3, nrow=5)
colnames(ur.all.saa) = c("tau", "p", "S")
rownames(ur.all.saa) = colnames(ibd_br.saa)[2:6]

# Perform one-sided Mann-Kendall calculations.
# H0: no monotonic trend; H1: negative monotonic trend
# Data is ranked for the test in terms of distances from
# a point of origin.
for(i in 1:nrow(ur.all.saa)){
  mk = mk.test(ibd_br.saa$PU[order(ibd_br.saa[,i+1])],
               alternative = "less")
  # assign tau-values
  ur.all.saa[i,1] <- round(mk$estimates[[3]],3)
  # assign p-values
  ur.all.saa[i,2] <- round(mk$p.value,3)
  # assign S-values
  ur.all.saa[i,3] <- mk$estimates[[1]]
}
ur.all.saa


## Excluding Samoyedic
# Create the matrix
ur.NoSam.saa = matrix(ncol=3, nrow=5)
colnames(ur.NoSam.saa) = c("tau", "p", "S")
rownames(ur.NoSam.saa) = colnames(ibd_br.saa)[2:6]

# Perform one-sided Mann-Kendall calculations.
# H0: no monotonic trend; H1: negative monotonic trend
# Data is ranked for the test in terms of distances
# from a point of origin.
ibd_br.NoSam.saa = ibd_br.saa[ibd_br.saa$Branches !="Samoyedic",]
for(i in 1:nrow(ur.NoSam.saa)){
  mk = mk.test(ibd_br.NoSam.saa$PU[order(ibd_br.NoSam.saa[,i+1])],
               alternative = "less")
  # assign tau-values
  ur.NoSam.saa[i,1] <- round(mk$estimates[[3]],3)
  # assign p-values
  ur.NoSam.saa[i,2] <- round(mk$p.value,3)
  # assign S-values
  ur.NoSam.saa[i,3] <- mk$estimates[[1]]
}
ur.NoSam.saa

### IBD for Indo-Iranian loans
## Including Samoyedic
# Create the matrix
ii.all.saa = matrix(ncol=3, nrow=5)
colnames(ii.all.saa) = c("tau", "p", "S")
rownames(ii.all.saa) = colnames(ibd_br.saa)[2:6]

# Perform one-sided Mann-Kendall calculations.
# H0: no monotonic trend; H1: negative monotonic trend
# Data is ranked for the test in terms of distances
# from a point of origin.
for(i in 1:nrow(ii.all.saa)){
  mk = mk.test(ibd_br.saa$II_Loans[order(ibd_br.saa[,i+1])],
               alternative = "less")
  # assign tau-values
  ii.all.saa[i,1] <- round(mk$estimates[[3]],3)
  # assign p-values
  ii.all.saa[i,2] <- round(mk$p.value,3)
  # assign S-values
  ii.all.saa[i,3] <- mk$estimates[[1]]
}
ii.all.saa

## Excluding Samoyedic
# Create the matrix
ii.NoSam.saa = matrix(ncol=3, nrow=5)
colnames(ii.NoSam.saa) = c("tau", "p", "S")
rownames(ii.NoSam.saa) = colnames(ibd_br.saa)[2:6]

# Perform one-sided Mann-Kendall calculations.
# H0: no monotonic trend; H1: negative monotonic trend
# Data is ranked for the test in terms of distances
# from a point of origin.
for(i in 1:nrow(ii.NoSam.saa)){
  mk = mk.test(ibd_br.NoSam.saa$II_Loans[order(ibd_br.NoSam.saa[,i+1])],
               alternative = "less")
  # assign tau-values
  ii.NoSam.saa[i,1] <- round(mk$estimates[[3]],3)
  # assign p-values
  ii.NoSam.saa[i,2] <- round(mk$p.value,3)
  # assign S-values
  ii.NoSam.saa[i,3] <- mk$estimates[[1]]
}
ii.NoSam.saa
